@@ -13,20 +13,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron.agent.linux import external_process
 from neutron.agent import rpc as agent_rpc
+from neutron.common import exceptions as n_exc
+from neutron import context as ncontext
+from neutron.i18n import _LE, _LI
+from neutron.openstack.common import loopingcall
+from neutron.openstack.common import periodic_task
+from neutron.plugins.common import constants
 from neutron.services import provider_configuration as provconfig
-from neutron_lib import constants
-from neutron_lib import context as ncontext
-from neutron_lib import exceptions as n_exc
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging
-from oslo_service import loopingcall
-from oslo_service import periodic_task
 from oslo_utils import importutils
 
-from neutron_lbaas._i18n import _
 from neutron_lbaas.agent import agent_api
 from neutron_lbaas.drivers.common import agent_driver_base
 from neutron_lbaas.services.loadbalancer import constants as lb_const
@@ -41,18 +40,13 @@ OPTS = [
         'device_driver',
         default=['neutron_lbaas.drivers.haproxy.'
                  'namespace_driver.HaproxyNSDriver'],
-        deprecated_for_removal=True,
-        deprecated_since='Queens',
-        deprecated_reason='The neutron-lbaas project is now deprecated. '
-                          'See: https://wiki.openstack.org/wiki/Neutron/LBaaS/'
-                          'Deprecation',
         help=_('Drivers used to manage loadbalancing devices'),
     ),
 ]
 
 
 class DeviceNotFoundOnAgent(n_exc.NotFound):
-    message = _('Unknown device with loadbalancer_id %(loadbalancer_id)s')
+    msg = _('Unknown device with loadbalancer_id %(loadbalancer_id)s')
 
 
 class LbaasAgentManager(periodic_task.PeriodicTasks):
@@ -62,7 +56,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
     target = oslo_messaging.Target(version='1.0')
 
     def __init__(self, conf):
-        super(LbaasAgentManager, self).__init__(conf)
+        super(LbaasAgentManager, self).__init__()
         self.conf = conf
         self.context = ncontext.get_admin_context_without_session()
         self.serializer = agent_driver_base.DataModelSerializer()
@@ -71,8 +65,6 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             self.context,
             self.conf.host
         )
-        self._process_monitor = external_process.ProcessMonitor(
-            config=self.conf, resource_type='loadbalancer')
         self._load_drivers()
 
         self.agent_state = {
@@ -98,8 +90,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
                 driver_inst = importutils.import_object(
                     driver,
                     self.conf,
-                    self.plugin_rpc,
-                    self._process_monitor
+                    self.plugin_rpc
                 )
             except ImportError:
                 msg = _('Error importing loadbalancer device driver: %s')
@@ -128,7 +119,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             self.state_rpc.report_state(self.context, self.agent_state)
             self.agent_state.pop('start_flag', None)
         except Exception:
-            LOG.exception("Failed reporting state!")
+            LOG.exception(_LE("Failed reporting state!"))
 
     def initialize_service_hook(self, started_by):
         self.sync_state()
@@ -149,7 +140,8 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
                     self.plugin_rpc.update_loadbalancer_stats(
                         loadbalancer_id, stats)
             except Exception:
-                LOG.exception('Error updating statistics on loadbalancer %s',
+                LOG.exception(_LE('Error updating statistics on loadbalancer'
+                                  ' %s'),
                               loadbalancer_id)
                 self.needs_resync = True
 
@@ -165,7 +157,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
                 self._reload_loadbalancer(loadbalancer_id)
 
         except Exception:
-            LOG.exception('Unable to retrieve ready devices')
+            LOG.exception(_LE('Unable to retrieve ready devices'))
             self.needs_resync = True
 
         self.remove_orphans()
@@ -185,7 +177,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
                 loadbalancer_dict)
             driver_name = loadbalancer.provider.device_driver
             if driver_name not in self.device_drivers:
-                LOG.error('No device driver on agent: %s.', driver_name)
+                LOG.error(_LE('No device driver on agent: %s.'), driver_name)
                 self.plugin_rpc.update_status(
                     'loadbalancer', loadbalancer_id, constants.ERROR)
                 return
@@ -194,7 +186,8 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             self.instance_mapping[loadbalancer_id] = driver_name
             self.plugin_rpc.loadbalancer_deployed(loadbalancer_id)
         except Exception:
-            LOG.exception('Unable to deploy instance for loadbalancer: %s',
+            LOG.exception(_LE('Unable to deploy instance for '
+                              'loadbalancer: %s'),
                           loadbalancer_id)
             self.needs_resync = True
 
@@ -205,7 +198,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             del self.instance_mapping[lb_id]
             self.plugin_rpc.loadbalancer_destroyed(lb_id)
         except Exception:
-            LOG.exception('Unable to destroy device for loadbalancer: %s',
+            LOG.exception(_LE('Unable to destroy device for loadbalancer: %s'),
                           lb_id)
             self.needs_resync = True
 
@@ -220,8 +213,8 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
 
     def _handle_failed_driver_call(self, operation, obj, driver):
         obj_type = obj.__class__.__name__.lower()
-        LOG.exception('%(operation)s %(obj)s %(id)s failed on device '
-                      'driver %(driver)s',
+        LOG.exception(_LE('%(operation)s %(obj)s %(id)s failed on device '
+                          'driver %(driver)s'),
                       {'operation': operation.capitalize(), 'obj': obj_type,
                        'id': obj.id, 'driver': driver})
         self._update_statuses(obj, error=True)
@@ -233,12 +226,11 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             if self.admin_state_up:
                 self.needs_resync = True
             else:
-                # Copy keys since the dictionary is modified in the loop body
-                for loadbalancer_id in list(self.instance_mapping.keys()):
-                    LOG.info("Destroying loadbalancer %s due to agent "
-                             "disabling", loadbalancer_id)
+                for loadbalancer_id in self.instance_mapping.keys():
+                    LOG.info(_LI("Destroying loadbalancer %s due to agent "
+                                 "disabling"), loadbalancer_id)
                     self._destroy_loadbalancer(loadbalancer_id)
-            LOG.info("Agent_updated by server side %s!", payload)
+            LOG.info(_LI("Agent_updated by server side %s!"), payload)
 
     def _update_statuses(self, obj, error=False):
         lb_p_status = constants.ACTIVE
@@ -269,7 +261,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
     def create_loadbalancer(self, context, loadbalancer, driver_name):
         loadbalancer = data_models.LoadBalancer.from_dict(loadbalancer)
         if driver_name not in self.device_drivers:
-            LOG.error('No device driver on agent: %s.', driver_name)
+            LOG.error(_LE('No device driver on agent: %s.'), driver_name)
             self.plugin_rpc.update_status('loadbalancer', loadbalancer.id,
                                           provisioning_status=constants.ERROR)
             return
@@ -331,7 +323,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
 
     def create_pool(self, context, pool):
         pool = data_models.Pool.from_dict(pool)
-        driver = self._get_driver(pool.loadbalancer.id)
+        driver = self._get_driver(pool.listener.loadbalancer.id)
         try:
             driver.pool.create(pool)
         except Exception:
@@ -342,7 +334,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
     def update_pool(self, context, old_pool, pool):
         pool = data_models.Pool.from_dict(pool)
         old_pool = data_models.Pool.from_dict(old_pool)
-        driver = self._get_driver(pool.loadbalancer.id)
+        driver = self._get_driver(pool.listener.loadbalancer.id)
         try:
             driver.pool.update(old_pool, pool)
         except Exception:
@@ -352,12 +344,12 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
 
     def delete_pool(self, context, pool):
         pool = data_models.Pool.from_dict(pool)
-        driver = self._get_driver(pool.loadbalancer.id)
+        driver = self._get_driver(pool.listener.loadbalancer.id)
         driver.pool.delete(pool)
 
     def create_member(self, context, member):
         member = data_models.Member.from_dict(member)
-        driver = self._get_driver(member.pool.loadbalancer.id)
+        driver = self._get_driver(member.pool.listener.loadbalancer.id)
         try:
             driver.member.create(member)
         except Exception:
@@ -369,7 +361,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
     def update_member(self, context, old_member, member):
         member = data_models.Member.from_dict(member)
         old_member = data_models.Member.from_dict(old_member)
-        driver = self._get_driver(member.pool.loadbalancer.id)
+        driver = self._get_driver(member.pool.listener.loadbalancer.id)
         try:
             driver.member.update(old_member, member)
         except Exception:
@@ -380,12 +372,12 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
 
     def delete_member(self, context, member):
         member = data_models.Member.from_dict(member)
-        driver = self._get_driver(member.pool.loadbalancer.id)
+        driver = self._get_driver(member.pool.listener.loadbalancer.id)
         driver.member.delete(member)
 
     def create_healthmonitor(self, context, healthmonitor):
         healthmonitor = data_models.HealthMonitor.from_dict(healthmonitor)
-        driver = self._get_driver(healthmonitor.pool.loadbalancer.id)
+        driver = self._get_driver(healthmonitor.pool.listener.loadbalancer.id)
         try:
             driver.healthmonitor.create(healthmonitor)
         except Exception:
@@ -399,7 +391,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
         healthmonitor = data_models.HealthMonitor.from_dict(healthmonitor)
         old_healthmonitor = data_models.HealthMonitor.from_dict(
             old_healthmonitor)
-        driver = self._get_driver(healthmonitor.pool.loadbalancer.id)
+        driver = self._get_driver(healthmonitor.pool.listener.loadbalancer.id)
         try:
             driver.healthmonitor.update(old_healthmonitor, healthmonitor)
         except Exception:
@@ -410,5 +402,5 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
 
     def delete_healthmonitor(self, context, healthmonitor):
         healthmonitor = data_models.HealthMonitor.from_dict(healthmonitor)
-        driver = self._get_driver(healthmonitor.pool.loadbalancer.id)
+        driver = self._get_driver(healthmonitor.pool.listener.loadbalancer.id)
         driver.healthmonitor.delete(healthmonitor)
