@@ -12,32 +12,27 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import importlib
+
 from oslo_config import cfg
-from stevedore import driver
 
 CONF = cfg.CONF
 
-CERT_MANAGER_DEFAULT = 'barbican'
+CERT_MANAGER_DEFAULT = ('neutron_lbaas.common.cert_manager.'
+                        'barbican_cert_manager')
 
 cert_manager_opts = [
-    cfg.StrOpt('cert_manager_type',
+    cfg.StrOpt('cert_manager_class',
                default=CERT_MANAGER_DEFAULT,
                help='Certificate Manager plugin. '
-                    'Defaults to {0}.'.format(CERT_MANAGER_DEFAULT)),
-    cfg.StrOpt('barbican_auth',
-               default='barbican_acl_auth',
-               help='Name of the Barbican authentication method to use')
+                    'Defaults to {0}.'.format(CERT_MANAGER_DEFAULT))
 ]
 
 CONF.register_opts(cert_manager_opts, group='certificates')
 
-_CERT_MANAGER_PLUGIN = None
-
-
-def get_backend():
-    global _CERT_MANAGER_PLUGIN
-    if not _CERT_MANAGER_PLUGIN:
-        _CERT_MANAGER_PLUGIN = driver.DriverManager(
-            "neutron_lbaas.cert_manager.backend",
-            cfg.CONF.certificates.cert_manager_type).driver
-    return _CERT_MANAGER_PLUGIN
+# Use CERT_MANAGER_PLUGIN.CertManager and CERT_MANAGER_PLUGIN.Cert to reference
+#   the Certificate plugin chosen via the service configuration.
+# TODO(rm_work): Investigate using Stevedore here.
+CERT_MANAGER_PLUGIN = importlib.import_module(
+    CONF.certificates.cert_manager_class
+)
