@@ -21,15 +21,15 @@ Create Date: 2015-01-18 10:00:00
 
 """
 
+# revision identifiers, used by Alembic.
+revision = 'lbaasv2_tls'
+down_revision = '364f9b6064f0'
+
 from alembic import op
 import sqlalchemy as sa
 
 from neutron.db import migration
 
-# revision identifiers, used by Alembic.
-revision = 'lbaasv2_tls'
-down_revision = '364f9b6064f0'
-
 
 old_listener_protocols = sa.Enum("HTTP", "HTTPS", "TCP",
                              name="listener_protocolsv2")
@@ -52,3 +52,10 @@ def upgrade():
     op.add_column('lbaas_listeners',
                   sa.Column(u'default_tls_container_id', sa.String(128),
                             nullable=True))
+
+
+def downgrade():
+    migration.alter_enum('lbaas_listeners', 'protocol', old_listener_protocols,
+                         nullable=False)
+    op.drop_table('lbaas_sni')
+    op.drop_column('lbaas_listeners', 'default_tls_container_id')
