@@ -16,31 +16,20 @@
 
 import abc
 
-from neutron_lib.api import converters
-from neutron_lib.api import extensions as api_extensions
-from neutron_lib.api import validators
-from neutron_lib import constants as n_constants
-from neutron_lib.db import constants as db_const
-from neutron_lib import exceptions as nexception
-from neutron_lib.plugins import constants
-from neutron_lib.plugins import directory
-from neutron_lib.services import base as service_base
 from oslo_config import cfg
-from oslo_log import log as logging
 import six
 
 from neutron.api import extensions
+from neutron.api.v2 import attributes as attr
 from neutron.api.v2 import base
 from neutron.api.v2 import resource_helper
-from neutron.quota import resource_registry
+from neutron.common import exceptions as nexception
+from neutron import manager
+from neutron.plugins.common import constants
+from neutron.services import service_base
 
-from neutron_lbaas._i18n import _
 from neutron_lbaas.services.loadbalancer import constants as lb_const
 
-LOADBALANCERV2_PREFIX = "/lbaas"
-
-LOG = logging.getLogger(__name__)
-
 
 # Loadbalancer Exceptions
 # This exception is only for a workaround when having v1 and v2 lbaas extension
@@ -85,7 +74,7 @@ class AttributeIDImmutable(nexception.NeutronException):
     message = _("Cannot change %(attribute)s if one already exists")
 
 
-class StateInvalid(nexception.Conflict):
+class StateInvalid(nexception.NeutronException):
     message = _("Invalid state %(state)s of loadbalancer resource %(id)s")
 
 
@@ -105,7 +94,12 @@ class MemberAddressTypeSubnetTypeMismatch(nexception.NeutronException):
 
 
 class DriverError(nexception.NeutronException):
-    message = _("Driver error: %(msg)s")
+    message = _("An error happened in the driver")
+
+
+class LBConfigurationUnsupported(nexception.NeutronException):
+    message = _("Load balancer %(load_balancer_id)s configuration is not "
+                "supported by driver %(driver_name)s")
 
 
 class SessionPersistenceConfigurationInvalid(nexception.BadRequest):
@@ -124,39 +118,6 @@ class TLSContainerInvalid(nexception.NeutronException):
     message = _("TLS container %(container_id)s is invalid. %(reason)s")
 
 
-class CertManagerError(nexception.NeutronException):
-    message = _("Could not process TLS container %(ref)s, %(reason)s")
-
-
-class ProviderFlavorConflict(nexception.Conflict):
-    message = _("Cannot specify both a flavor and a provider")
-
-
-class FlavorsPluginNotLoaded(nexception.NotFound):
-    message = _("Flavors plugin not found")
-
-
-def _validate_connection_limit(data, min_value=lb_const.MIN_CONNECT_VALUE):
-    if int(data) < min_value:
-        msg = (_("'%(data)s' is not a valid value, "
-                 "because it cannot be less than %(min_value)s") %
-               {'data': data, 'min_value': min_value})
-        LOG.debug(msg)
-        return msg
-
-validators.validators['type:connection_limit'] = _validate_connection_limit
-
-
-def _validate_db_limit(data, max_value=db_const.DB_INTEGER_MAX_VALUE):
-    if int(data) > max_value:
-        msg = (_("'%(data)s' is not a valid value, "
-                 "because it is more than %(max_value)s") %
-               {'data': data, 'max_value': max_value})
-        LOG.debug(msg)
-        return msg
-
-validators.validators['type:db_out_of_bounds'] = _validate_db_limit
-
 RESOURCE_ATTRIBUTE_MAP = {
     'loadbalancers': {
         'id': {'allow_post': False, 'allow_put': False,
@@ -164,44 +125,38 @@ RESOURCE_ATTRIBUTE_MAP = {
                'is_visible': True,
                'primary_key': True},
         'name': {'allow_post': True, 'allow_put': True,
-                 'validate': {'type:string': db_const.NAME_FIELD_SIZE},
+                 'validate': {'type:string': None},
                  'default': '',
                  'is_visible': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
-                      'validate': {'type:not_empty_string':
-                                   db_const.PROJECT_ID_FIELD_SIZE},
+                      'validate': {'type:string': None},
                       'required_by_policy': True,
                       'is_visible': True},
         'description': {'allow_post': True, 'allow_put': True,
-                        'validate': {
-                            'type:string': db_const.DESCRIPTION_FIELD_SIZE},
+                        'validate': {'type:string': None},
                         'is_visible': True, 'default': ''},
         'vip_subnet_id': {'allow_post': True, 'allow_put': False,
                           'validate': {'type:uuid': None},
                           'is_visible': True},
         'vip_address': {'allow_post': True, 'allow_put': False,
-                        'default': n_constants.ATTR_NOT_SPECIFIED,
+                        'default': attr.ATTR_NOT_SPECIFIED,
                         'validate': {'type:ip_address_or_none': None},
                         'is_visible': True},
         'vip_port_id': {'allow_post': False, 'allow_put': False,
                         'is_visible': True},
         'provider': {'allow_post': True, 'allow_put': False,
-                     'validate': {'type:string': None}, 'is_visible': True,
-                     'default': n_constants.ATTR_NOT_SPECIFIED},
+                     'validate': {'type:string': None},
+                     'is_visible': True, 'default': attr.ATTR_NOT_SPECIFIED},
         'listeners': {'allow_post': False, 'allow_put': False,
                       'is_visible': True},
         'admin_state_up': {'allow_post': True, 'allow_put': True,
                            'default': True,
-                           'convert_to': converters.convert_to_boolean,
+                           'convert_to': attr.convert_to_boolean,
                            'is_visible': True},
         'provisioning_status': {'allow_post': False, 'allow_put': False,
                                 'is_visible': True},
         'operating_status': {'allow_post': False, 'allow_put': False,
-                             'is_visible': True},
-        'flavor_id': {'allow_post': True, 'allow_put': False,
-                      'is_visible': True,
-                      'validate': {'type:string': db_const.NAME_FIELD_SIZE},
-                      'default': n_constants.ATTR_NOT_SPECIFIED}
+                             'is_visible': True}
     },
     'listeners': {
         'id': {'allow_post': False, 'allow_put': False,
@@ -209,17 +164,15 @@ RESOURCE_ATTRIBUTE_MAP = {
                'is_visible': True,
                'primary_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
-                      'validate': {'type:not_empty_string':
-                                   db_const.PROJECT_ID_FIELD_SIZE},
+                      'validate': {'type:string': None},
                       'required_by_policy': True,
                       'is_visible': True},
         'name': {'allow_post': True, 'allow_put': True,
-                 'validate': {'type:string': db_const.NAME_FIELD_SIZE},
+                 'validate': {'type:string': None},
                  'default': '',
                  'is_visible': True},
         'description': {'allow_post': True, 'allow_put': True,
-                        'validate': {
-                            'type:string': db_const.DESCRIPTION_FIELD_SIZE},
+                        'validate': {'type:string': None},
                         'is_visible': True, 'default': ''},
         'loadbalancer_id': {'allow_post': True, 'allow_put': False,
                             'validate': {'type:uuid': None},
@@ -229,32 +182,30 @@ RESOURCE_ATTRIBUTE_MAP = {
         'default_pool_id': {'allow_post': False, 'allow_put': False,
                             'validate': {'type:uuid': None},
                             'is_visible': True},
-        'default_tls_container_ref': {'allow_post': True,
-                                      'allow_put': True,
-                                      'default': None,
-                                      'validate': {'type:string_or_none': 128},
-                                      'is_visible': True},
-        'sni_container_refs': {'allow_post': True, 'allow_put': True,
-                               'default': None,
-                               'convert_to': converters.convert_to_list,
-                               'is_visible': True},
+        'default_tls_container_id': {'allow_post': True,
+                                     'allow_put': True,
+                                     'default': None,
+                                     'validate': {'type:string_or_none': 128},
+                                     'is_visible': True},
+        'sni_container_ids': {'allow_post': True, 'allow_put': True,
+                              'default': None,
+                              'convert_to': attr.convert_to_list,
+                              'is_visible': True},
         'connection_limit': {'allow_post': True, 'allow_put': True,
-                             'validate': {'type:connection_limit':
-                                          lb_const.MIN_CONNECT_VALUE},
-                             'default': lb_const.MIN_CONNECT_VALUE,
-                             'convert_to': converters.convert_to_int,
+                             'default': -1,
+                             'convert_to': attr.convert_to_int,
                              'is_visible': True},
         'protocol': {'allow_post': True, 'allow_put': False,
                      'validate': {'type:values':
                                   lb_const.LISTENER_SUPPORTED_PROTOCOLS},
                      'is_visible': True},
         'protocol_port': {'allow_post': True, 'allow_put': False,
-                          'validate': {'type:range': [1, 65535]},
-                          'convert_to': converters.convert_to_int,
+                          'validate': {'type:range': [0, 65535]},
+                          'convert_to': attr.convert_to_int,
                           'is_visible': True},
         'admin_state_up': {'allow_post': True, 'allow_put': True,
                            'default': True,
-                           'convert_to': converters.convert_to_boolean,
+                           'convert_to': attr.convert_to_boolean,
                            'is_visible': True}
     },
     'pools': {
@@ -263,16 +214,14 @@ RESOURCE_ATTRIBUTE_MAP = {
                'is_visible': True,
                'primary_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
-                      'validate': {'type:not_empty_string':
-                                   db_const.PROJECT_ID_FIELD_SIZE},
+                      'validate': {'type:string': None},
                       'required_by_policy': True,
                       'is_visible': True},
         'name': {'allow_post': True, 'allow_put': True,
-                 'validate': {'type:string': db_const.NAME_FIELD_SIZE},
+                 'validate': {'type:string': None},
                  'is_visible': True, 'default': ''},
         'description': {'allow_post': True, 'allow_put': True,
-                        'validate': {
-                            'type:string': db_const.DESCRIPTION_FIELD_SIZE},
+                        'validate': {'type:string': None},
                         'is_visible': True, 'default': ''},
         'listener_id': {'allow_post': True, 'allow_put': False,
                         'validate': {'type:uuid': None},
@@ -292,7 +241,7 @@ RESOURCE_ATTRIBUTE_MAP = {
                          'is_visible': True},
         'session_persistence': {
             'allow_post': True, 'allow_put': True,
-            'convert_to': converters.convert_none_to_empty_dict,
+            'convert_to': attr.convert_none_to_empty_dict,
             'default': {},
             'validate': {
                 'type:dict_or_empty': {
@@ -306,7 +255,7 @@ RESOURCE_ATTRIBUTE_MAP = {
                     'is_visible': True},
         'admin_state_up': {'allow_post': True, 'allow_put': True,
                            'default': True,
-                           'convert_to': converters.convert_to_boolean,
+                           'convert_to': attr.convert_to_boolean,
                            'is_visible': True}
     },
     'healthmonitors': {
@@ -315,8 +264,7 @@ RESOURCE_ATTRIBUTE_MAP = {
                'is_visible': True,
                'primary_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
-                      'validate': {'type:not_empty_string':
-                                   db_const.PROJECT_ID_FIELD_SIZE},
+                      'validate': {'type:string': None},
                       'required_by_policy': True,
                       'is_visible': True},
         'pool_id': {'allow_post': True, 'allow_put': False,
@@ -329,28 +277,23 @@ RESOURCE_ATTRIBUTE_MAP = {
                      'type:values': lb_const.SUPPORTED_HEALTH_MONITOR_TYPES},
                  'is_visible': True},
         'delay': {'allow_post': True, 'allow_put': True,
-                  'validate': {
-                      'type:db_out_of_bounds':
-                          db_const.DB_INTEGER_MAX_VALUE,
-                      'type:non_negative': None},
-                  'convert_to': converters.convert_to_int,
+                  'validate': {'type:non_negative': None},
+                  'convert_to': attr.convert_to_int,
                   'is_visible': True},
         'timeout': {'allow_post': True, 'allow_put': True,
                     'validate': {'type:non_negative': None},
-                    'convert_to': converters.convert_to_int,
+                    'convert_to': attr.convert_to_int,
                     'is_visible': True},
         'max_retries': {'allow_post': True, 'allow_put': True,
                         'validate': {'type:range': [1, 10]},
-                        'convert_to': converters.convert_to_int,
+                        'convert_to': attr.convert_to_int,
                         'is_visible': True},
         'http_method': {'allow_post': True, 'allow_put': True,
-                        'validate': {'type:values':
-                                     lb_const.SUPPORTED_HTTP_METHODS},
+                        'validate': {'type:string': None},
                         'default': 'GET',
                         'is_visible': True},
         'url_path': {'allow_post': True, 'allow_put': True,
-                     'validate': {'type:regex_or_none':
-                                  lb_const.SUPPORTED_URL_PATH},
+                     'validate': {'type:string': None},
                      'default': '/',
                      'is_visible': True},
         'expected_codes': {
@@ -364,12 +307,8 @@ RESOURCE_ATTRIBUTE_MAP = {
         },
         'admin_state_up': {'allow_post': True, 'allow_put': True,
                            'default': True,
-                           'convert_to': converters.convert_to_boolean,
-                           'is_visible': True},
-        'name': {'allow_post': True, 'allow_put': True,
-                 'validate': {'type:string': db_const.NAME_FIELD_SIZE},
-                 'default': '',
-                 'is_visible': True}
+                           'convert_to': attr.convert_to_boolean,
+                           'is_visible': True}
     }
 }
 
@@ -383,33 +322,29 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
                    'is_visible': True,
                    'primary_key': True},
             'tenant_id': {'allow_post': True, 'allow_put': False,
-                          'validate': {'type:not_empty_string':
-                                       db_const.PROJECT_ID_FIELD_SIZE},
+                          'validate': {'type:string': None},
                           'required_by_policy': True,
                           'is_visible': True},
             'address': {'allow_post': True, 'allow_put': False,
                         'validate': {'type:ip_address': None},
                         'is_visible': True},
             'protocol_port': {'allow_post': True, 'allow_put': False,
-                              'validate': {'type:range': [1, 65535]},
-                              'convert_to': converters.convert_to_int,
+                              'validate': {'type:range': [0, 65535]},
+                              'convert_to': attr.convert_to_int,
                               'is_visible': True},
             'weight': {'allow_post': True, 'allow_put': True,
                        'default': 1,
-                       'validate': {'type:range': [0, 256],
-                                    'type:integer': None},
+                       'validate': {'type:range': [0, 256]},
+                       'convert_to': attr.convert_to_int,
                        'is_visible': True},
             'admin_state_up': {'allow_post': True, 'allow_put': True,
                                'default': True,
-                               'convert_to': converters.convert_to_boolean,
+                               'convert_to': attr.convert_to_boolean,
                                'is_visible': True},
             'subnet_id': {'allow_post': True, 'allow_put': False,
                           'validate': {'type:uuid': None},
                           'is_visible': True},
-            'name': {'allow_post': True, 'allow_put': True,
-                     'validate': {'type:string': db_const.NAME_FIELD_SIZE},
-                     'default': '',
-                     'is_visible': True},
+
         }
     }
 }
@@ -418,54 +353,29 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
 lbaasv2_quota_opts = [
     cfg.IntOpt('quota_loadbalancer',
                default=10,
-               deprecated_for_removal=True,
-               deprecated_since='Queens',
-               deprecated_reason='The neutron-lbaas project is now '
-                                 'deprecated. See: https://wiki.openstack.org/'
-                                 'wiki/Neutron/LBaaS/Deprecation',
                help=_('Number of LoadBalancers allowed per tenant. '
                       'A negative value means unlimited.')),
     cfg.IntOpt('quota_listener',
                default=-1,
-               deprecated_for_removal=True,
-               deprecated_since='Queens',
-               deprecated_reason='The neutron-lbaas project is now '
-                                 'deprecated. See: https://wiki.openstack.org/'
-                                 'wiki/Neutron/LBaaS/Deprecation',
                help=_('Number of Loadbalancer Listeners allowed per tenant. '
                       'A negative value means unlimited.')),
     cfg.IntOpt('quota_pool',
                default=10,
-               deprecated_for_removal=True,
-               deprecated_since='Queens',
-               deprecated_reason='The neutron-lbaas project is now '
-                                 'deprecated. See: https://wiki.openstack.org/'
-                                 'wiki/Neutron/LBaaS/Deprecation',
                help=_('Number of pools allowed per tenant. '
                       'A negative value means unlimited.')),
     cfg.IntOpt('quota_member',
                default=-1,
-               deprecated_for_removal=True,
-               deprecated_since='Queens',
-               deprecated_reason='The neutron-lbaas project is now '
-                                 'deprecated. See: https://wiki.openstack.org/'
-                                 'wiki/Neutron/LBaaS/Deprecation',
                help=_('Number of pool members allowed per tenant. '
                       'A negative value means unlimited.')),
     cfg.IntOpt('quota_healthmonitor',
                default=-1,
-               deprecated_for_removal=True,
-               deprecated_since='Queens',
-               deprecated_reason='The neutron-lbaas project is now '
-                                 'deprecated. See: https://wiki.openstack.org/'
-                                 'wiki/Neutron/LBaaS/Deprecation',
                help=_('Number of health monitors allowed per tenant. '
                       'A negative value means unlimited.'))
 ]
 cfg.CONF.register_opts(lbaasv2_quota_opts, 'QUOTAS')
 
 
-class Loadbalancerv2(api_extensions.ExtensionDescriptor):
+class Loadbalancerv2(extensions.ExtensionDescriptor):
 
     @classmethod
     def get_name(cls):
@@ -477,11 +387,15 @@ class Loadbalancerv2(api_extensions.ExtensionDescriptor):
 
     @classmethod
     def get_description(cls):
-        return "Extension for LoadBalancing service v2 (deprecated)"
+        return "Extension for LoadBalancing service v2"
+
+    @classmethod
+    def get_namespace(cls):
+        return "http://wiki.openstack.org/neutron/LBaaS/API_2.0"
 
     @classmethod
     def get_updated(cls):
-        return "2018-01-31T10:00:00-00:00"
+        return "2014-06-18T10:00:00-00:00"
 
     @classmethod
     def get_resources(cls):
@@ -489,16 +403,16 @@ class Loadbalancerv2(api_extensions.ExtensionDescriptor):
             {}, RESOURCE_ATTRIBUTE_MAP)
         action_map = {'loadbalancer': {'stats': 'GET', 'statuses': 'GET'}}
         plural_mappings['members'] = 'member'
-        resource_registry.register_resource_by_name('member', 'members')
-        plural_mappings['sni_container_refs'] = 'sni_container_ref'
         plural_mappings['sni_container_ids'] = 'sni_container_id'
+        attr.PLURALS.update(plural_mappings)
         resources = resource_helper.build_resource_info(
             plural_mappings,
             RESOURCE_ATTRIBUTE_MAP,
             constants.LOADBALANCERV2,
             action_map=action_map,
             register_quota=True)
-        plugin = directory.get_plugin(constants.LOADBALANCERV2)
+        plugin = manager.NeutronManager.get_service_plugins()[
+            constants.LOADBALANCERV2]
         for collection_name in SUB_RESOURCE_ATTRIBUTE_MAP:
             # Special handling needed for sub-resources with 'y' ending
             # (e.g. proxies -> proxy)
@@ -517,7 +431,8 @@ class Loadbalancerv2(api_extensions.ExtensionDescriptor):
             resource = extensions.ResourceExtension(
                 collection_name,
                 controller, parent,
-                path_prefix=LOADBALANCERV2_PREFIX,
+                path_prefix=constants.COMMON_PREFIXES[
+                    constants.LOADBALANCERV2],
                 attr_map=params)
             resources.append(resource)
 
@@ -548,7 +463,7 @@ class LoadBalancerPluginBaseV2(service_base.ServicePluginBase):
         return constants.LOADBALANCERV2
 
     def get_plugin_description(self):
-        return 'LoadBalancer service plugin v2 (deprecated)'
+        return 'LoadBalancer service plugin v2'
 
     @abc.abstractmethod
     def get_loadbalancers(self, context, filters=None, fields=None):
@@ -668,48 +583,3 @@ class LoadBalancerPluginBaseV2(service_base.ServicePluginBase):
     @abc.abstractmethod
     def statuses(self, context, loadbalancer_id):
         pass
-
-    @abc.abstractmethod
-    def get_l7policies(self, context, filters=None, fields=None):
-        pass
-
-    @abc.abstractmethod
-    def get_l7policy(self, context, id, fields=None):
-        pass
-
-    @abc.abstractmethod
-    def create_l7policy(self, context, l7policy):
-        pass
-
-    @abc.abstractmethod
-    def update_l7policy(self, context, id, l7policy):
-        pass
-
-    @abc.abstractmethod
-    def delete_l7policy(self, context, id):
-        pass
-
-    @abc.abstractmethod
-    def get_l7policy_rules(self, context, l7policy_id,
-                           filters=None, fields=None):
-        pass
-
-    @abc.abstractmethod
-    def get_l7policy_rule(self, context, id, l7policy_id, fields=None):
-        pass
-
-    @abc.abstractmethod
-    def create_l7policy_rule(self, context, rule, l7policy_id):
-        pass
-
-    @abc.abstractmethod
-    def update_l7policy_rule(self, context, id, rule, l7policy_id):
-        pass
-
-    @abc.abstractmethod
-    def delete_l7policy_rule(self, context, id, l7policy_id):
-        pass
-
-    @abc.abstractmethod
-    def create_graph(self, context, graph):
-        pass
