@@ -13,21 +13,21 @@
 #    under the License.
 
 from neutron.agent import rpc as agent_rpc
+from neutron.common import constants as n_const
+from neutron.common import exceptions as n_exc
+from neutron.common import topics
 from neutron import context as ncontext
-from neutron.plugins.common import constants as np_const
+from neutron.i18n import _LE, _LI
+from neutron.openstack.common import loopingcall
+from neutron.openstack.common import periodic_task
+from neutron.plugins.common import constants
 from neutron.services import provider_configuration as provconfig
-from neutron_lib import constants as n_const
-from neutron_lib import exceptions as n_exc
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging
-from oslo_service import loopingcall
-from oslo_service import periodic_task
 from oslo_utils import importutils
 
-from neutron_lbaas._i18n import _, _LE, _LI
 from neutron_lbaas.services.loadbalancer.agent import agent_api
-from neutron_lbaas.services.loadbalancer import constants as l_const
 
 LOG = logging.getLogger(__name__)
 
@@ -44,7 +44,7 @@ OPTS = [
 
 
 class DeviceNotFoundOnAgent(n_exc.NotFound):
-    message = _('Unknown device with pool_id %(pool_id)s')
+    msg = _('Unknown device with pool_id %(pool_id)s')
 
 
 class LbaasAgentManager(periodic_task.PeriodicTasks):
@@ -59,11 +59,11 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
     target = oslo_messaging.Target(version='2.0')
 
     def __init__(self, conf):
-        super(LbaasAgentManager, self).__init__(conf)
+        super(LbaasAgentManager, self).__init__()
         self.conf = conf
         self.context = ncontext.get_admin_context_without_session()
         self.plugin_rpc = agent_api.LbaasAgentApi(
-            l_const.LOADBALANCER_PLUGIN,
+            topics.LOADBALANCER_PLUGIN,
             self.context,
             self.conf.host
         )
@@ -72,7 +72,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
         self.agent_state = {
             'binary': 'neutron-lbaas-agent',
             'host': conf.host,
-            'topic': l_const.LOADBALANCER_AGENT,
+            'topic': topics.LOADBALANCER_AGENT,
             'configurations': {'device_drivers': self.device_drivers.keys()},
             'agent_type': n_const.AGENT_TYPE_LOADBALANCER,
             'start_flag': True}
@@ -107,7 +107,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
 
     def _setup_state_rpc(self):
         self.state_rpc = agent_rpc.PluginReportStateAPI(
-            l_const.LOADBALANCER_PLUGIN)
+            topics.LOADBALANCER_PLUGIN)
         report_interval = self.conf.AGENT.report_interval
         if report_interval:
             heartbeat = loopingcall.FixedIntervalLoopingCall(
@@ -177,7 +177,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             if driver_name not in self.device_drivers:
                 LOG.error(_LE('No device driver on agent: %s.'), driver_name)
                 self.plugin_rpc.update_status(
-                    'pool', pool_id, np_const.ERROR)
+                    'pool', pool_id, constants.ERROR)
                 return
 
             self.device_drivers[driver_name].deploy_instance(logical_config)
@@ -213,13 +213,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
                           'driver %(driver)s'),
                       {'operation': operation.capitalize(), 'obj': obj_type,
                        'id': obj_id, 'driver': driver})
-        self.plugin_rpc.update_status(obj_type, obj_id, np_const.ERROR)
-
-    def _update_status(self, obj_type, obj_id, admin_state_up):
-        if admin_state_up:
-            self.plugin_rpc.update_status(obj_type, obj_id, np_const.ACTIVE)
-        else:
-            self.plugin_rpc.update_status(obj_type, obj_id, l_const.DISABLED)
+        self.plugin_rpc.update_status(obj_type, obj_id, constants.ERROR)
 
     def create_vip(self, context, vip):
         driver = self._get_driver(vip['pool_id'])
@@ -229,7 +223,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             self._handle_failed_driver_call('create', 'vip', vip['id'],
                                             driver.get_name())
         else:
-            self._update_status('vip', vip['id'], vip['admin_state_up'])
+            self.plugin_rpc.update_status('vip', vip['id'], constants.ACTIVE)
 
     def update_vip(self, context, old_vip, vip):
         driver = self._get_driver(vip['pool_id'])
@@ -239,7 +233,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             self._handle_failed_driver_call('update', 'vip', vip['id'],
                                             driver.get_name())
         else:
-            self._update_status('vip', vip['id'], vip['admin_state_up'])
+            self.plugin_rpc.update_status('vip', vip['id'], constants.ACTIVE)
 
     def delete_vip(self, context, vip):
         driver = self._get_driver(vip['pool_id'])
@@ -248,7 +242,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
     def create_pool(self, context, pool, driver_name):
         if driver_name not in self.device_drivers:
             LOG.error(_LE('No device driver on agent: %s.'), driver_name)
-            self.plugin_rpc.update_status('pool', pool['id'], np_const.ERROR)
+            self.plugin_rpc.update_status('pool', pool['id'], constants.ERROR)
             return
 
         driver = self.device_drivers[driver_name]
@@ -259,7 +253,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
                                             driver.get_name())
         else:
             self.instance_mapping[pool['id']] = driver_name
-            self._update_status('pool', pool['id'], pool['admin_state_up'])
+            self.plugin_rpc.update_status('pool', pool['id'], constants.ACTIVE)
 
     def update_pool(self, context, old_pool, pool):
         driver = self._get_driver(pool['id'])
@@ -269,7 +263,7 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             self._handle_failed_driver_call('update', 'pool', pool['id'],
                                             driver.get_name())
         else:
-            self._update_status('pool', pool['id'], pool['admin_state_up'])
+            self.plugin_rpc.update_status('pool', pool['id'], constants.ACTIVE)
 
     def delete_pool(self, context, pool):
         driver = self._get_driver(pool['id'])
@@ -284,8 +278,8 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             self._handle_failed_driver_call('create', 'member', member['id'],
                                             driver.get_name())
         else:
-            self._update_status('member', member['id'],
-                                member['admin_state_up'])
+            self.plugin_rpc.update_status('member', member['id'],
+                                          constants.ACTIVE)
 
     def update_member(self, context, old_member, member):
         driver = self._get_driver(member['pool_id'])
@@ -295,8 +289,8 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             self._handle_failed_driver_call('update', 'member', member['id'],
                                             driver.get_name())
         else:
-            self._update_status('member', member['id'],
-                                member['admin_state_up'])
+            self.plugin_rpc.update_status('member', member['id'],
+                                          constants.ACTIVE)
 
     def delete_member(self, context, member):
         driver = self._get_driver(member['pool_id'])
@@ -311,8 +305,8 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             self._handle_failed_driver_call(
                 'create', 'health_monitor', assoc_id, driver.get_name())
         else:
-            self._update_status('health_monitor', assoc_id,
-                                health_monitor['admin_state_up'])
+            self.plugin_rpc.update_status(
+                'health_monitor', assoc_id, constants.ACTIVE)
 
     def update_pool_health_monitor(self, context, old_health_monitor,
                                    health_monitor, pool_id):
@@ -326,8 +320,8 @@ class LbaasAgentManager(periodic_task.PeriodicTasks):
             self._handle_failed_driver_call(
                 'update', 'health_monitor', assoc_id, driver.get_name())
         else:
-            self._update_status('health_monitor', assoc_id,
-                                health_monitor['admin_state_up'])
+            self.plugin_rpc.update_status(
+                'health_monitor', assoc_id, constants.ACTIVE)
 
     def delete_pool_health_monitor(self, context, health_monitor, pool_id):
         driver = self._get_driver(pool_id)
