@@ -14,20 +14,17 @@
 #    under the License.
 
 import random
-import sys
 
+from neutron.common import constants
 from neutron.db import agents_db
 from neutron.db import agentschedulers_db
 from neutron.db import model_base
-from neutron_lib import constants
+from neutron.i18n import _LW
 from oslo_log import log as logging
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.orm import joinedload
 
-from abc import abstractmethod
-from neutron_lbaas._i18n import _LW
 from neutron_lbaas.extensions import lbaas_agentscheduler
 
 LOG = logging.getLogger(__name__)
@@ -64,7 +61,7 @@ class LbaasAgentSchedulerDbMixin(agentschedulers_db.AgentSchedulerDbMixin,
         if active is not None:
             query = query.filter_by(admin_state_up=active)
         if filters:
-            for key, value in six.iteritems(filters):
+            for key, value in filters.iteritems():
                 column = getattr(agents_db.Agent, key, None)
                 if column:
                     query = query.filter(column.in_(value))
@@ -82,11 +79,6 @@ class LbaasAgentSchedulerDbMixin(agentschedulers_db.AgentSchedulerDbMixin,
         else:
             return {'pools': []}
 
-    def num_of_pools_on_lbaas_agent(self, context, id):
-        query = context.session.query(PoolLoadbalancerAgentBinding.pool_id)
-        query = query.filter_by(agent_id=id)
-        return query.count()
-
     def get_lbaas_agent_candidates(self, device_driver, active_agents):
         candidates = []
         for agent in active_agents:
@@ -96,7 +88,8 @@ class LbaasAgentSchedulerDbMixin(agentschedulers_db.AgentSchedulerDbMixin,
         return candidates
 
 
-class SchedulerBase(object):
+class ChanceScheduler(object):
+    """Allocate a loadbalancer agent for a vip in a random way."""
 
     def schedule(self, plugin, context, pool, device_driver):
         """Schedule the pool to an active loadbalancer agent if there
@@ -114,19 +107,17 @@ class SchedulerBase(object):
 
             active_agents = plugin.get_lbaas_agents(context, active=True)
             if not active_agents:
-                LOG.warning(_LW('No active lbaas agents for pool %s'),
-                            pool['id'])
+                LOG.warn(_LW('No active lbaas agents for pool %s'), pool['id'])
                 return
 
             candidates = plugin.get_lbaas_agent_candidates(device_driver,
                                                            active_agents)
             if not candidates:
-                LOG.warning(_LW('No lbaas agent supporting device driver %s'),
-                            device_driver)
+                LOG.warn(_LW('No lbaas agent supporting device driver %s'),
+                         device_driver)
                 return
 
-            chosen_agent = self._schedule(candidates, plugin, context)
-
+            chosen_agent = random.choice(candidates)
             binding = PoolLoadbalancerAgentBinding()
             binding.agent = chosen_agent
             binding.pool_id = pool['id']
@@ -136,29 +127,3 @@ class SchedulerBase(object):
                       {'pool_id': pool['id'],
                        'agent_id': chosen_agent['id']})
             return chosen_agent
-
-    @abstractmethod
-    def _schedule(self, candidates, plugin, context):
-        pass
-
-
-class ChanceScheduler(SchedulerBase):
-
-    def _schedule(self, candidates, plugin, context):
-        """Allocate a loadbalancer agent for a vip in a random way."""
-        return random.choice(candidates)
-
-
-class LeastPoolAgentScheduler(SchedulerBase):
-
-    def _schedule(self, candidates, plugin, context):
-        """Pick an agent with least number of pools from candidates"""
-        current_min_pool_num = sys.maxint
-        # SchedulerBase.schedule() already checks for empty candidates
-        for tmp_agent in candidates:
-            tmp_pool_num = plugin.num_of_pools_on_lbaas_agent(
-                context, tmp_agent['id'])
-            if current_min_pool_num > tmp_pool_num:
-                current_min_pool_num = tmp_pool_num
-                chosen_agent = tmp_agent
-        return chosen_agent
