@@ -14,22 +14,22 @@
 
 import uuid
 
+from neutron.common import constants as q_const
+from neutron.common import exceptions as n_exc
 from neutron.common import rpc as n_rpc
+from neutron.common import topics
 from neutron.db import agents_db
 from neutron.extensions import portbindings
-from neutron.plugins.common import constants as np_const
+from neutron.i18n import _LW
+from neutron.plugins.common import constants
 from neutron.services import provider_configuration as provconf
-from neutron_lib import constants as q_const
-from neutron_lib import exceptions as n_exc
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging
 from oslo_utils import importutils
 
-from neutron_lbaas._i18n import _, _LW
 from neutron_lbaas.db.loadbalancer import loadbalancer_db
 from neutron_lbaas.extensions import lbaas_agentscheduler
-from neutron_lbaas.services.loadbalancer import constants as l_const
 from neutron_lbaas.services.loadbalancer.drivers import abstract_driver
 
 LOG = logging.getLogger(__name__)
@@ -82,7 +82,7 @@ class LoadBalancerCallbacks(object):
             qry = qry.filter(loadbalancer_db.Pool.id.in_(pool_ids))
             qry = qry.filter(
                 loadbalancer_db.Pool.status.in_(
-                    np_const.ACTIVE_PENDING_STATUSES))
+                    constants.ACTIVE_PENDING_STATUSES))
             up = True  # makes pep8 and sqlalchemy happy
             qry = qry.filter(loadbalancer_db.Pool.admin_state_up == up)
             return [id for id, in qry]
@@ -110,13 +110,13 @@ class LoadBalancerCallbacks(object):
             retval['members'] = [
                 self.plugin._make_member_dict(m)
                 for m in pool.members if (
-                    m.status in np_const.ACTIVE_PENDING_STATUSES or
-                    m.status == np_const.INACTIVE)
+                    m.status in constants.ACTIVE_PENDING_STATUSES or
+                    m.status == constants.INACTIVE)
             ]
             retval['healthmonitors'] = [
                 self.plugin._make_health_monitor_dict(hm.healthmonitor)
                 for hm in pool.monitors
-                if hm.status in np_const.ACTIVE_PENDING_STATUSES
+                if hm.status in constants.ACTIVE_PENDING_STATUSES
             ]
             retval['driver'] = (
                 self.plugin.drivers[pool.provider.provider_name].device_driver)
@@ -130,20 +130,20 @@ class LoadBalancerCallbacks(object):
             pool = qry.one()
 
             # set all resources to active
-            if pool.status in np_const.ACTIVE_PENDING_STATUSES:
-                pool.status = np_const.ACTIVE
+            if pool.status in constants.ACTIVE_PENDING_STATUSES:
+                pool.status = constants.ACTIVE
 
             if (pool.vip and pool.vip.status in
-                    np_const.ACTIVE_PENDING_STATUSES):
-                pool.vip.status = np_const.ACTIVE
+                    constants.ACTIVE_PENDING_STATUSES):
+                pool.vip.status = constants.ACTIVE
 
             for m in pool.members:
-                if m.status in np_const.ACTIVE_PENDING_STATUSES:
-                    m.status = np_const.ACTIVE
+                if m.status in constants.ACTIVE_PENDING_STATUSES:
+                    m.status = constants.ACTIVE
 
             for hm in pool.monitors:
-                if hm.status in np_const.ACTIVE_PENDING_STATUSES:
-                    hm.status = np_const.ACTIVE
+                if hm.status in constants.ACTIVE_PENDING_STATUSES:
+                    hm.status = constants.ACTIVE
 
     def update_status(self, context, obj_type, obj_id, status):
         model_mapping = {
@@ -191,7 +191,7 @@ class LoadBalancerCallbacks(object):
             return
 
         port['admin_state_up'] = True
-        port['device_owner'] = 'neutron:' + np_const.LOADBALANCER
+        port['device_owner'] = 'neutron:' + constants.LOADBALANCER
         port['device_id'] = str(uuid.uuid5(uuid.NAMESPACE_DNS, str(host)))
         port[portbindings.HOST_ID] = host
         self.plugin._core_plugin.update_port(
@@ -322,7 +322,7 @@ class AgentDriverBase(abstract_driver.LoadBalancerAbstractDriver):
         if not self.device_driver:
             raise DriverNotSpecified()
 
-        self.agent_rpc = LoadBalancerAgentApi(l_const.LOADBALANCER_AGENT)
+        self.agent_rpc = LoadBalancerAgentApi(topics.LOADBALANCER_AGENT)
 
         self.plugin = plugin
         self._set_callbacks_on_plugin()
@@ -342,9 +342,9 @@ class AgentDriverBase(abstract_driver.LoadBalancerAbstractDriver):
             LoadBalancerCallbacks(self.plugin),
             agents_db.AgentExtRpcCallback(self.plugin)
         ]
-        self.plugin.conn = n_rpc.create_connection()
+        self.plugin.conn = n_rpc.create_connection(new=True)
         self.plugin.conn.create_consumer(
-            l_const.LOADBALANCER_PLUGIN,
+            topics.LOADBALANCER_PLUGIN,
             self.plugin.agent_endpoints,
             fanout=False)
         self.plugin.conn.consume_in_threads()
@@ -361,7 +361,7 @@ class AgentDriverBase(abstract_driver.LoadBalancerAbstractDriver):
 
     def update_vip(self, context, old_vip, vip):
         agent = self.get_pool_agent(context, vip['pool_id'])
-        if vip['status'] in np_const.ACTIVE_PENDING_STATUSES:
+        if vip['status'] in constants.ACTIVE_PENDING_STATUSES:
             self.agent_rpc.update_vip(context, old_vip, vip, agent['host'])
         else:
             self.agent_rpc.delete_vip(context, vip, agent['host'])
@@ -381,7 +381,7 @@ class AgentDriverBase(abstract_driver.LoadBalancerAbstractDriver):
 
     def update_pool(self, context, old_pool, pool):
         agent = self.get_pool_agent(context, pool['id'])
-        if pool['status'] in np_const.ACTIVE_PENDING_STATUSES:
+        if pool['status'] in constants.ACTIVE_PENDING_STATUSES:
             self.agent_rpc.update_pool(context, old_pool, pool,
                                        agent['host'])
         else:
