@@ -17,10 +17,10 @@ from heleosapi import exceptions as h_exc
 from neutron import context
 from neutron.db import servicetype_db as sdb
 from neutron.i18n import _LE
+from neutron.openstack.common import loopingcall
 from neutron.plugins.common import constants as ccon
 from neutron.plugins.embrane.common import contexts as embrane_ctx
 from oslo_log import log as logging
-from oslo_service import loopingcall
 
 from neutron_lbaas.db.loadbalancer import loadbalancer_db as ldb
 from neutron_lbaas.services.loadbalancer.drivers.embrane \
