@@ -17,17 +17,16 @@ import os
 import jinja2
 import six
 
-from neutron.common import utils as n_utils
+from neutron.agent.linux import utils
 from neutron.plugins.common import constants as plugin_constants
 from oslo_config import cfg
 
-from neutron_lbaas._i18n import _
 from neutron_lbaas.common import cert_manager
 from neutron_lbaas.common.tls_utils import cert_parser
 from neutron_lbaas.services.loadbalancer import constants
 from neutron_lbaas.services.loadbalancer import data_models
 
-CERT_MANAGER_PLUGIN = cert_manager.get_backend()
+CERT_MANAGER_PLUGIN = cert_manager.CERT_MANAGER_PLUGIN
 
 PROTOCOL_MAP = {
     constants.PROTOCOL_TCP: 'tcp',
@@ -88,13 +87,13 @@ def save_config(conf_path, loadbalancer, socket_path, user_group,
                                          user_group,
                                          socket_path,
                                          haproxy_base_dir)
-    n_utils.replace_file(conf_path, config_str)
+    utils.replace_file(conf_path, config_str)
 
 
 def _get_template():
     """Retrieve Jinja template
 
-    :returns: Jinja template
+    :return: Jinja template
     """
     global JINJA_ENV
     if not JINJA_ENV:
@@ -112,13 +111,13 @@ def _store_listener_crt(haproxy_base_dir, listener, cert):
     :param haproxy_base_dir: location of the instances state data
     :param listener: the listener object
     :param cert: the TLS certificate
-    :returns: location of the stored certificate
+    :return: location of the stored certificate
     """
     cert_path = _retrieve_crt_path(haproxy_base_dir, listener,
                                    cert.primary_cn)
     # build a string that represents the pem file to be saved
     pem = _build_pem(cert)
-    n_utils.replace_file(cert_path, pem)
+    utils.replace_file(cert_path, pem)
     return cert_path
 
 
@@ -128,7 +127,7 @@ def _retrieve_crt_path(haproxy_base_dir, listener, primary_cn):
     :param haproxy_base_dir: location of the instances state data
     :param listener: the listener object
     :param primary_cn: primary_cn used for identifying TLS certificate
-    :returns: TLS certificate location
+    :return: TLS certificate location
     """
     confs_dir = os.path.abspath(os.path.normpath(haproxy_base_dir))
     confs_path = os.path.join(confs_dir, listener.id)
@@ -144,8 +143,8 @@ def _process_tls_certificates(listener):
 
     Converts and uploads PEM data to the Amphora API
 
-    :param listener: the listener object
-    :returns: TLS_CERT and SNI_CERTS
+    :param listener the listener object
+    :return: TLS_CERT and SNI_CERTS
     """
     cert_mgr = CERT_MANAGER_PLUGIN.CertManager()
 
@@ -155,25 +154,13 @@ def _process_tls_certificates(listener):
     if listener.default_tls_container_id:
         tls_cert = _map_cert_tls_container(
             cert_mgr.get_cert(
-                project_id=listener.tenant_id,
-                cert_ref=listener.default_tls_container_id,
-                resource_ref=cert_mgr.get_service_url(
-                    listener.loadbalancer_id),
-                check_only=True
-            )
-        )
+                listener.default_tls_container_id,
+                check_only=True))
     if listener.sni_containers:
         # Retrieve, map and store SNI certificates
         for sni_cont in listener.sni_containers:
             cert_container = _map_cert_tls_container(
-                cert_mgr.get_cert(
-                    project_id=listener.tenant_id,
-                    cert_ref=sni_cont.tls_container_id,
-                    resource_ref=cert_mgr.get_service_url(
-                        listener.loadbalancer_id),
-                    check_only=True
-                )
-            )
+                cert_mgr.get_cert(sni_cont.tls_container_id, check_only=True))
             sni_certs.append(cert_container)
 
     return {'tls_cert': tls_cert, 'sni_certs': sni_certs}
@@ -183,7 +170,7 @@ def _get_primary_cn(tls_cert):
     """Retrieve primary cn for TLS certificate
 
     :param tls_cert: the TLS certificate
-    :returns: primary cn of the TLS certificate
+    :return: primary cn of the TLS certificate
     """
     return cert_parser.get_host_names(tls_cert)['cn']
 
@@ -192,7 +179,7 @@ def _map_cert_tls_container(cert):
     """Map cert data to TLS data model
 
     :param cert: TLS certificate
-    :returns: mapped TLSContainer object
+    :return: mapped TLSContainer object
     """
     certificate = cert.get_certificate()
     pkey = cert_parser.dump_private_key(cert.get_private_key(),
@@ -208,7 +195,7 @@ def _build_pem(tls_cert):
     """Generate PEM encoded TLS certificate data
 
     :param tls_cert: TLS certificate
-    :returns: PEm encoded certificate data
+    :return: PEm encoded certificate data
     """
     pem = ()
     if tls_cert.intermediates:
@@ -229,7 +216,7 @@ def render_loadbalancer_obj(loadbalancer, user_group, socket_path,
     :param user_group: the user group
     :param socket_path: location of the instances socket data
     :param haproxy_base_dir:  location of the instances state data
-    :returns: rendered load balancer configuration
+    :return: rendered load balancer configuration
     """
     loadbalancer = _transform_loadbalancer(loadbalancer, haproxy_base_dir)
     return _get_template().render({'loadbalancer': loadbalancer,
@@ -243,16 +230,14 @@ def _transform_loadbalancer(loadbalancer, haproxy_base_dir):
 
     :param loadbalancer: the load balancer object
     :param haproxy_base_dir: location of the instances state data
-    :returns: dictionary of transformed load balancer values
+    :return: dictionary of transformed load balancer values
     """
-    listeners = [_transform_listener(x, haproxy_base_dir)
-        for x in loadbalancer.listeners if x.admin_state_up]
-    pools = [_transform_pool(x) for x in loadbalancer.pools]
+    listeners = [_transform_listener(
+        x, haproxy_base_dir) for x in loadbalancer.listeners]
     return {
         'name': loadbalancer.name,
         'vip_address': loadbalancer.vip_address,
-        'listeners': listeners,
-        'pools': pools
+        'listeners': listeners
     }
 
 
@@ -261,7 +246,7 @@ def _transform_listener(listener, haproxy_base_dir):
 
     :param listener: the listener object
     :param haproxy_base_dir: location of the instances state data
-    :returns: dictionary of transformed listener values
+    :return: dictionary of transformed listener values
     """
     data_dir = os.path.join(haproxy_base_dir, listener.id)
     ret_value = {
@@ -291,7 +276,7 @@ def _transform_pool(pool):
     """Transforms pool object
 
     :param pool: the pool object
-    :returns: dictionary of transformed pool values
+    :return: dictionary of transformed pool values
     """
     ret_value = {
         'id': pool.id,
@@ -306,7 +291,7 @@ def _transform_pool(pool):
     members = [_transform_member(x)
                for x in pool.members if _include_member(x)]
     ret_value['members'] = members
-    if pool.healthmonitor and pool.healthmonitor.admin_state_up:
+    if pool.healthmonitor:
         ret_value['health_monitor'] = _transform_health_monitor(
             pool.healthmonitor)
     if pool.session_persistence:
@@ -319,7 +304,7 @@ def _transform_session_persistence(persistence):
     """Transforms session persistence object
 
     :param persistence: the session persistence object
-    :returns: dictionary of transformed session persistence values
+    :return: dictionary of transformed session persistence values
     """
     return {
         'type': persistence.type,
@@ -331,7 +316,7 @@ def _transform_member(member):
     """Transforms member object
 
     :param member: the member object
-    :returns: dictionary of transformed member values
+    :return: dictionary of transformed member values
     """
     return {
         'id': member.id,
@@ -348,7 +333,7 @@ def _transform_health_monitor(monitor):
     """Transforms health monitor object
 
     :param monitor: the health monitor object
-    :returns: dictionary of transformed health monitor values
+    :return: dictionary of transformed health monitor values
     """
     return {
         'id': monitor.id,
@@ -368,7 +353,7 @@ def _include_member(member):
     """Helper for verifying member statues
 
     :param member: the member object
-    :returns: boolean of status check
+    :return: boolean of status check
     """
     return (member.provisioning_status in
             MEMBER_STATUSES and member.admin_state_up)
@@ -378,7 +363,7 @@ def _expand_expected_codes(codes):
     """Expand the expected code string in set of codes
 
     :param codes: string of status codes
-    :returns: list of status codes
+    :return: list of status codes
     """
 
     retval = set()
@@ -390,7 +375,7 @@ def _expand_expected_codes(codes):
         elif '-' in code:
             low, hi = code.split('-')[:2]
             retval.update(
-                str(i) for i in six.moves.range(int(low), int(hi) + 1))
+                str(i) for i in six.moves.xrange(int(low), int(hi) + 1))
         else:
             retval.add(code)
     return retval
