@@ -12,12 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from neutron.i18n import _LW
 from oslo_log import log as logging
 
-from neutron_lbaas._i18n import _LW
 from neutron_lbaas.drivers import logging_noop
 
 LOG = logging.getLogger(__name__)
-LOG.warning(_LW("This path has been deprecated. "
-                "Use neutron_lbaas.drivers.logging_noop instead."))
+LOG.warn(_LW("This path has been deprecated. "
+             "Use neutron_lbaas.drivers.logging_noop instead."))
 __path__ = logging_noop.__path__
