@@ -14,11 +14,6 @@
 #    under the License.
 #
 
-import mock
-import webob
-
-from neutron.db import servicetype_db as st_db
-from neutron.quota import resource_registry
 from neutron.tests import base as n_base
 from neutron.tests.unit.db import test_db_base_plugin_v2
 from neutron.tests.unit.extensions import base as ext_base
@@ -34,17 +29,6 @@ class BaseTestCase(n_base.BaseTestCase):
 class NeutronDbPluginV2TestCase(
     test_db_base_plugin_v2.NeutronDbPluginV2TestCase):
 
-    def set_override(self, lbaas_provider):
-        # override the default service provider
-        self.service_providers = (
-            mock.patch.object(st_db.ServiceTypeManager,
-                              'get_service_providers').start())
-        self.service_providers.return_value = (
-            self._to_provider_dicts(lbaas_provider))
-
-        # need to reload provider configuration
-        st_db.ServiceTypeManager._instance = None
-
     def new_list_request(self, resource, fmt=None, params=None, id=None,
                          subresource=None):
         return self._req(
@@ -61,27 +45,13 @@ class NeutronDbPluginV2TestCase(
         return self._req('GET', resource, None, fmt, id=id,
                          params=params, subresource=subresource, sub_id=sub_id)
 
-    def new_update_request_lbaas(self, resource, data, id, fmt=None,
+    def new_update_request(self, resource, data, id, fmt=None,
                            subresource=None, context=None, sub_id=None):
         return self._req(
             'PUT', resource, data, fmt, id=id, subresource=subresource,
             context=context, sub_id=sub_id
         )
 
-    def _to_provider_dicts(self, lbaas_provider):
-        provider_dicts = []
-        for provider in lbaas_provider:
-            bits = provider.split(':')
-            p = {
-                'service_type': bits[0],
-                'name': bits[1],
-                'driver': bits[2]
-            }
-            if len(bits) == 4:
-                p['default'] = True
-            provider_dicts.append(p)
-        return provider_dicts
-
     def _test_list_with_sort(self, resource,
                              items, sorts, resources=None,
                              query_params='',
@@ -208,28 +178,10 @@ class NeutronDbPluginV2TestCase(
         expected_res.reverse()
         self.assertEqual(expected_res, [n['id'] for n in item_res])
 
-    def _delete(self, collection, id,
-                expected_code=webob.exc.HTTPNoContent.code,
-                neutron_context=None, subresource=None, sub_id=None):
-        req = self.new_delete_request(collection, id, subresource=subresource,
-                                      sub_id=sub_id)
-        if neutron_context:
-            # create a specific auth context for this request
-            req.environ['neutron.context'] = neutron_context
-        res = req.get_response(self._api_for_resource(collection))
-        self.assertEqual(res.status_int, expected_code)
-
 
 class ExtensionTestCase(ext_base.ExtensionTestCase):
     pass
 
 
 class QuotaExtensionTestCase(test_quotasv2.QuotaExtensionTestCase):
-
-    def setUp(self):
-        super(QuotaExtensionTestCase, self).setUp()
-        resource_registry.register_resource_by_name('pool')
-        resource_registry.register_resource_by_name('loadbalancer')
-        resource_registry.register_resource_by_name('listener')
-        resource_registry.register_resource_by_name('healthmonitor')
-        resource_registry.register_resource_by_name('member')
+    pass
