@@ -13,8 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import sys
-
+import contextlib
 import mock
 from oslo_config import cfg
 
@@ -36,14 +35,14 @@ class TestLbaasService(base.BaseTestCase):
             self.assertTrue(mock_start.called)
 
     def test_main(self):
-        logging_str = 'neutron.conf.agent.common.setup_logging'
-        privsep_str = 'neutron.conf.agent.common.setup_privsep'
-        with mock.patch(logging_str), \
-                mock.patch(privsep_str), \
-                mock.patch.object(agent.service, 'launch') as mock_launch, \
-                mock.patch.object(sys, 'argv', ['neutron-lbaasv2-agent']), \
-                mock.patch.object(agent.manager, 'LbaasAgentManager'), \
-                mock.patch.object(cfg.CONF, 'register_opts'):
+        logging_str = 'neutron.agent.common.config.setup_logging'
+        with contextlib.nested(
+            mock.patch(logging_str),
+            mock.patch.object(agent.service, 'launch'),
+            mock.patch('sys.argv'),
+            mock.patch.object(agent.manager, 'LbaasAgentManager'),
+            mock.patch.object(cfg.CONF, 'register_opts')
+        ) as (mock_logging, mock_launch, sys_argv, mgr_cls, ro):
             agent.main()
 
-            mock_launch.assert_called_once_with(mock.ANY, mock.ANY)
+            mock_launch.assert_called_once_with(mock.ANY)
