@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import contextlib
 import copy
 import mock
 
@@ -27,8 +28,8 @@ class TestApiCache(base.BaseTestCase):
         self.api = api.LbaasAgentApi('topic', mock.sentinel.context, 'host')
 
     def test_init(self):
-        self.assertEqual('host', self.api.host)
-        self.assertEqual(mock.sentinel.context, self.api.context)
+        self.assertEqual(self.api.host, 'host')
+        self.assertEqual(self.api.context, mock.sentinel.context)
 
     def _test_method(self, method, **kwargs):
         add_host = ('get_ready_devices', 'plug_vip_port', 'unplug_vip_port')
@@ -36,13 +37,17 @@ class TestApiCache(base.BaseTestCase):
         if method in add_host:
             expected_kwargs['host'] = self.api.host
 
-        with mock.patch.object(self.api.client, 'call') as rpc_mock, \
-                mock.patch.object(self.api.client, 'prepare') as prepare_mock:
+        with contextlib.nested(
+            mock.patch.object(self.api.client, 'call'),
+            mock.patch.object(self.api.client, 'prepare'),
+        ) as (
+            rpc_mock, prepare_mock
+        ):
             prepare_mock.return_value = self.api.client
             rpc_mock.return_value = 'foo'
             rv = getattr(self.api, method)(**kwargs)
 
-        self.assertEqual('foo', rv)
+        self.assertEqual(rv, 'foo')
 
         prepare_args = {}
         prepare_mock.assert_called_once_with(**prepare_args)
