@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+#
 # Copyright 2014 Brocade Communications Systems, Inc.
 # All Rights Reserved.
 #
@@ -18,12 +20,12 @@
 import sys
 
 import mock
-from neutron_lib import context
+from neutron import context
 
 with mock.patch.dict(sys.modules, {'brocade_neutron_lbaas': mock.Mock()}):
     from neutron_lbaas.drivers.brocade import driver_v2 as driver
 from neutron_lbaas.services.loadbalancer import data_models
-from neutron_lbaas.tests.unit.db.loadbalancer import test_db_loadbalancerv2
+from neutron_lbaas.tests.unit.db.loadbalancer import test_db_loadbalancer
 
 
 class FakeModel(object):
@@ -72,17 +74,16 @@ class LoadBalancerManagerTest(ManagerTest):
 
 
 class TestBrocadeLoadBalancerDriver(
-        test_db_loadbalancerv2.LbaasPluginDbTestCase):
+        test_db_loadbalancer.LoadBalancerPluginDbTestCase):
 
     def _create_fake_models(self):
         id = 'name-001'
         lb = data_models.LoadBalancer(id=id)
         listener = data_models.Listener(id=id, loadbalancer=lb)
-        pool = data_models.Pool(id=id, loadbalancer=lb)
+        pool = data_models.Pool(id=id, listener=listener)
         member = data_models.Member(id=id, pool=pool)
         hm = data_models.HealthMonitor(id=id, pool=pool)
         lb.listeners = [listener]
-        lb.pools = [pool]
         listener.default_pool = pool
         pool.members = [member]
         pool.healthmonitor = hm
