@@ -15,12 +15,11 @@
 
 import mock
 
+from neutron import context
+from neutron.extensions import portbindings
+from neutron.openstack.common import uuidutils
+from neutron.plugins.common import constants
 from neutron.tests.unit import testlib_api
-from neutron_lib.api.definitions import portbindings
-from neutron_lib import constants
-from neutron_lib import context
-from neutron_lib.plugins import constants as n_constants
-from oslo_utils import uuidutils
 from six import moves
 
 from neutron_lbaas.db.loadbalancer import loadbalancer_dbv2 as ldb
@@ -60,7 +59,7 @@ class TestLoadBalancerCallbacks(
                 ready = self.callbacks.get_ready_devices(
                     context.get_admin_context(),
                 )
-                self.assertEqual([lb_id], ready)
+                self.assertEqual(ready, [lb_id])
 
     def test_get_ready_devices_multiple_listeners_and_loadbalancers(self):
         ctx = context.get_admin_context()
@@ -68,7 +67,7 @@ class TestLoadBalancerCallbacks(
         # add 3 load balancers and 2 listeners directly to DB
         # to create 2 "ready" devices and one load balancer without listener
         loadbalancers = []
-        for i in moves.range(3):
+        for i in moves.xrange(3):
             loadbalancers.append(ldb.models.LoadBalancer(
                 id=uuidutils.generate_uuid(), vip_subnet_id=self._subnet_id,
                 provisioning_status=constants.ACTIVE, admin_state_up=True,
@@ -95,14 +94,14 @@ class TestLoadBalancerCallbacks(
 
         ctx.session.flush()
 
-        self.assertEqual(3, ctx.session.query(ldb.models.LoadBalancer).count())
-        self.assertEqual(2, ctx.session.query(ldb.models.Listener).count())
+        self.assertEqual(ctx.session.query(ldb.models.LoadBalancer).count(), 3)
+        self.assertEqual(ctx.session.query(ldb.models.Listener).count(), 2)
         with mock.patch(
                 'neutron_lbaas.agent_scheduler.LbaasAgentSchedulerDbMixin'
                 '.list_loadbalancers_on_lbaas_agent') as mock_agent_lbs:
             mock_agent_lbs.return_value = loadbalancers
             ready = self.callbacks.get_ready_devices(ctx)
-            self.assertEqual(3, len(ready))
+            self.assertEqual(len(ready), 3)
             self.assertIn(loadbalancers[0].id, ready)
             self.assertIn(loadbalancers[1].id, ready)
             self.assertIn(loadbalancers[2].id, ready)
@@ -153,14 +152,7 @@ class TestLoadBalancerCallbacks(
             expected_lb['provider']['device_driver'] = 'dummy'
             subnet = self.plugin_instance.db._core_plugin.get_subnet(
                 ctx, expected_lb['vip_subnet_id'])
-            subnet = data_models.Subnet.from_dict(subnet).to_dict()
             expected_lb['vip_port']['fixed_ips'][0]['subnet'] = subnet
-            network = self.plugin_instance.db._core_plugin.get_network(
-                ctx, expected_lb['vip_port']['network_id']
-            )
-            expected_lb['vip_port']['network'] = {}
-            for key in ('id', 'name', 'description', 'mtu'):
-                expected_lb['vip_port']['network'][key] = network[key]
             del expected_lb['stats']
             self.assertEqual(expected_lb, load_balancer)
 
@@ -178,12 +170,11 @@ class TestLoadBalancerCallbacks(
             db_lb = self.plugin_instance.db.get_loadbalancer(ctx, lb_id)
             func(ctx, port_id=db_lb.vip_port_id, **kwargs)
             db_port = core.get_port(ctx, db_lb.vip_port_id)
-            for k, v in expected.items():
-                self.assertEqual(v, db_port[k])
+            for k, v in expected.iteritems():
+                self.assertEqual(db_port[k], v)
 
     def test_plug_vip_port(self):
         exp = {
-            'device_owner': 'neutron:' + n_constants.LOADBALANCERV2,
             'admin_state_up': True
         }
         self._update_port_test_helper(
@@ -194,7 +185,6 @@ class TestLoadBalancerCallbacks(
 
     def test_plug_vip_port_mock_with_host(self):
         exp = {
-            'device_owner': 'neutron:' + n_constants.LOADBALANCERV2,
             'admin_state_up': True,
             portbindings.HOST_ID: 'host'
         }
