@@ -14,17 +14,16 @@
 #    under the License.
 
 import collections
+import contextlib
 import socket
 
 import mock
-from neutron.agent.linux import external_process
-from neutron_lib import constants
-from neutron_lib import exceptions
+from neutron.common import exceptions
+from neutron.plugins.common import constants
 
 from neutron_lbaas.drivers.haproxy import namespace_driver
 from neutron_lbaas.services.loadbalancer import data_models
 from neutron_lbaas.tests import base
-from oslo_utils import fileutils
 
 
 class TestHaproxyNSDriver(base.BaseTestCase):
@@ -38,16 +37,14 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         conf.haproxy.user_group = 'test_group'
         conf.haproxy.send_gratuitous_arp = 3
         self.conf = conf
+        self.mock_importer = mock.patch.object(namespace_driver,
+                                               'importutils').start()
+
         self.rpc_mock = mock.Mock()
-        self.ensure_tree = mock.patch.object(fileutils, 'ensure_tree').start()
-        self._process_monitor = mock.Mock()
-        with mock.patch(
-                'neutron_lib.utils.runtime.load_class_by_alias_or_classname'):
-            self.driver = namespace_driver.HaproxyNSDriver(
-                conf,
-                self.rpc_mock,
-                self._process_monitor
-            )
+        self.driver = namespace_driver.HaproxyNSDriver(
+            conf,
+            self.rpc_mock
+        )
         self.vif_driver = mock.Mock()
         self.driver.vif_driver = self.vif_driver
         self._build_mock_data_models()
@@ -64,24 +61,25 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                                 mac_address='12-34-56-78-9A-BC',
                                 fixed_ips=[fixed_ip])
         self.lb = data_models.LoadBalancer(id='lb1', listeners=[],
-                                           vip_port=port,
-                                           vip_address='10.0.0.1')
+                                           vip_port=port)
 
     def test_get_name(self):
         self.assertEqual(namespace_driver.DRIVER_NAME, self.driver.get_name())
 
     @mock.patch('neutron.agent.linux.ip_lib.IPWrapper')
-    @mock.patch('os.makedirs')
     @mock.patch('os.path.dirname')
     @mock.patch('os.path.isdir')
     @mock.patch('shutil.rmtree')
     def test_undeploy_instance(self, mock_shutil, mock_isdir, mock_dirname,
-                               mock_makedirs, mock_ip_wrap):
+                               mock_ip_wrap):
         self.driver._get_state_file_path = mock.Mock(return_value='/path')
+        namespace_driver.kill_pids_in_file = mock.Mock()
         self.driver._unplug = mock.Mock()
         mock_dirname.return_value = '/path/' + self.lb.id
         mock_isdir.return_value = False
+
         self.driver.undeploy_instance(self.lb.id)
+        namespace_driver.kill_pids_in_file.assert_called_once_with('/path')
         calls = [mock.call(self.lb.id, 'pid'), mock.call(self.lb.id, '')]
         self.driver._get_state_file_path.has_calls(calls)
         self.assertFalse(self.driver._unplug.called)
@@ -91,6 +89,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
 
         self.driver.deployed_loadbalancers[self.lb.id] = self.lb
         mock_isdir.return_value = True
+        namespace_driver.kill_pids_in_file.reset_mock()
         mock_isdir.reset_mock()
         mock_ns = mock_ip_wrap.return_value
         mock_ns.get_devices.return_value = [collections.namedtuple(
@@ -98,6 +97,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         self.driver.undeploy_instance(self.lb.id, cleanup_namespace=True,
                                       delete_namespace=True)
         ns = namespace_driver.get_ns_name(self.lb.id)
+        namespace_driver.kill_pids_in_file.assert_called_once_with('/path')
         calls = [mock.call(self.lb.id, 'pid'), mock.call(self.lb.id, '')]
         self.driver._get_state_file_path.has_calls(calls)
         self.driver._unplug.assert_called_once_with(ns, self.lb.vip_port)
@@ -108,20 +108,6 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                                                        namespace=ns)
         mock_shutil.assert_called_once_with('/path/' + self.lb.id)
         mock_ns.garbage_collect_namespace.assert_called_once_with()
-        self.assertDictEqual(self.driver.deployed_loadbalancers, {})
-
-    @mock.patch('os.makedirs')
-    @mock.patch('os.path.dirname')
-    def test_undeploy_instance_unregister_usage(self, mock_dirname,
-                                                mock_makedirs):
-        self.driver._get_state_file_path = mock.Mock(return_value='/path')
-        self.driver._unplug = mock.Mock()
-        mock_dirname.return_value = '/path/' + self.lb.id
-        with mock.patch.object(self._process_monitor,
-                               'unregister') as mock_unregister:
-            self.driver.undeploy_instance(self.lb.id)
-            mock_unregister.assert_called_once_with(
-                    uuid=self.lb.id, service_name='lbaas-ns-haproxy')
 
     @mock.patch('os.path.exists')
     @mock.patch('os.listdir')
@@ -173,17 +159,15 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                            'hrsp_3xx,hrsp_4xx,hrsp_5xx,hrsp_other,hanafail,'
                            'req_rate,req_rate_max,req_tot,cli_abrt,srv_abrt,'
                            '\n')
-        with mock.patch.object(self.driver, '_get_state_file_path') as gsp, \
-                mock.patch('socket.socket') as mocket, \
-                mock.patch('os.path.exists') as path_exists, \
-                mock.patch.object(data_models.LoadBalancer, 'from_dict') \
-                as lb_from_dict, \
-                mock.patch.object(self.driver, '_is_active') as is_active:
+        with contextlib.nested(
+                mock.patch.object(self.driver, '_get_state_file_path'),
+                mock.patch('socket.socket'),
+                mock.patch('os.path.exists'),
+        ) as (gsp, mocket, path_exists):
             gsp.side_effect = lambda x, y, z: '/pool/' + y
             path_exists.return_value = True
             mocket.return_value = mocket
-            mocket.recv.return_value = raw_stats.encode('utf-8')
-            is_active.return_value = True
+            mocket.recv.return_value = raw_stats
 
             exp_stats = {'connection_errors': '0',
                          'active_connections': '3',
@@ -197,12 +181,12 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                          'total_connections': '10',
                          'members': {
                              '32a6c2a3-420a-44c3-955d-86bd2fc6871e': {
-                                 'operating_status': 'ONLINE',
+                                 'status': 'ACTIVE',
                                  'health': 'L7OK',
                                  'failed_checks': '0'
                              },
                              'd9aea044-8867-4e80-9875-16fb808fa0f9': {
-                                 'operating_status': 'OFFLINE',
+                                 'status': 'INACTIVE',
                                  'health': 'L4CON',
                                  'failed_checks': '9'
                              }
@@ -211,57 +195,15 @@ class TestHaproxyNSDriver(base.BaseTestCase):
             stats = self.driver.get_stats(self.lb.id)
             self.assertEqual(exp_stats, stats)
 
-            mocket.recv.return_value = raw_stats_empty.encode('utf-8')
+            mocket.recv.return_value = raw_stats_empty
             self.assertEqual({'members': {}},
                              self.driver.get_stats(self.lb.id))
 
-            path_exists.return_value = False
-            is_active.return_value = True
-            listener = data_models.Listener(
-                provisioning_status=constants.PENDING_CREATE,
-                admin_state_up=True)
-            self.lb.listeners.append(listener)
-            lb_from_dict.return_value = \
-                data_models.LoadBalancer.from_dict(self.lb)
-
-            self.lb.listeners.append(listener)
-            self.assertEqual({}, self.driver.get_stats(self.lb.id))
-
             path_exists.return_value = False
             mocket.reset_mock()
-            is_active.return_value = False
             self.assertEqual({}, self.driver.get_stats(self.lb.id))
             self.assertFalse(mocket.called)
 
-    def test_is_active(self):
-        # test no listeners
-        ret_val = self.driver._is_active(self.lb)
-        self.assertFalse(ret_val)
-
-        # test bad VIP status
-        listener = data_models.Listener(
-            provisioning_status=constants.PENDING_CREATE,
-            admin_state_up=True)
-        self.lb.listeners.append(listener)
-        self.lb.vip_port.status = constants.DOWN
-        ret_val = self.driver._is_active(self.lb)
-        self.assertFalse(ret_val)
-        self.lb.vip_port.status = constants.PENDING_CREATE
-        self.lb.vip_port.admin_state_up = False
-        ret_val = self.driver._is_active(self.lb)
-        self.assertFalse(ret_val)
-
-        # test bad LB status
-        self.lb.vip_port.admin_state_up = True
-        self.lb.operating_status = 'OFFLINE'
-        ret_val = self.driver._is_active(self.lb)
-        self.assertFalse(ret_val)
-
-        # test everything good
-        self.lb.operating_status = 'ONLINE'
-        ret_val = self.driver._is_active(self.lb)
-        self.assertTrue(ret_val)
-
     def test_deploy_instance(self):
         self.driver.deployable = mock.Mock(return_value=False)
         self.driver.exists = mock.Mock(return_value=True)
@@ -299,7 +241,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
     def test_update(self):
         self.driver._get_state_file_path = mock.Mock(return_value='/path')
         self.driver._spawn = mock.Mock()
-        with mock.patch('six.moves.builtins.open') as m_open:
+        with mock.patch('__builtin__.open') as m_open:
             file_mock = mock.MagicMock()
             m_open.return_value = file_mock
             file_mock.__enter__.return_value = file_mock
@@ -371,8 +313,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         self.driver._spawn = mock.Mock()
         self.driver.create(self.lb)
         self.driver._plug.assert_called_once_with(
-            namespace_driver.get_ns_name(self.lb.id),
-            self.lb.vip_port, self.lb.vip_address)
+            namespace_driver.get_ns_name(self.lb.id), self.lb.vip_port)
         self.driver._spawn.assert_called_once_with(self.lb)
 
     def test_deployable(self):
@@ -412,15 +353,15 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         ret_val = self.driver.deployable(self.lb)
         self.assertTrue(ret_val)
 
-    @mock.patch('oslo_utils.fileutils.ensure_tree')
-    def test_get_state_file_path(self, ensure_tree):
+    @mock.patch('neutron.agent.linux.utils.ensure_dir')
+    def test_get_state_file_path(self, ensure_dir):
         path = self.driver._get_state_file_path(self.lb.id, 'conf',
                                                 ensure_state_dir=False)
         self.assertEqual('/the/path/v2/lb1/conf', path)
-        self.assertFalse(ensure_tree.called)
+        self.assertFalse(ensure_dir.called)
         path = self.driver._get_state_file_path(self.lb.id, 'conf')
         self.assertEqual('/the/path/v2/lb1/conf', path)
-        self.assertTrue(ensure_tree.called)
+        self.assertTrue(ensure_dir.called)
 
     @mock.patch('neutron.agent.linux.ip_lib.device_exists')
     @mock.patch('neutron.agent.linux.ip_lib.IPWrapper')
@@ -429,8 +370,8 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         interface_name = 'tap-d4nc3'
         self.vif_driver.get_device_name.return_value = interface_name
         self.assertRaises(exceptions.PreexistingDeviceFailure,
-                          self.driver._plug, 'ns1', self.lb.vip_port,
-                          self.lb.vip_address, reuse_existing=False)
+                          self.driver._plug,
+                          'ns1', self.lb.vip_port, reuse_existing=False)
         device_exists.assert_called_once_with(interface_name,
                                               namespace='ns1')
         self.rpc_mock.plug_vip_port.assert_called_once_with(
@@ -439,7 +380,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         device_exists.reset_mock()
         self.rpc_mock.plug_vip_port.reset_mock()
         mock_ns = ip_wrap.return_value
-        self.driver._plug('ns1', self.lb.vip_port, self.lb.vip_address)
+        self.driver._plug('ns1', self.lb.vip_port)
         self.rpc_mock.plug_vip_port.assert_called_once_with(
             self.lb.vip_port.id)
         device_exists.assert_called_once_with(interface_name,
@@ -467,10 +408,11 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         self.vif_driver.unplug.assert_called_once_with(interface_name,
                                                        namespace='ns1')
 
-    @mock.patch('oslo_utils.fileutils.ensure_tree')
-    @mock.patch('neutron_lbaas.drivers.haproxy.jinja_cfg.save_config')
+    @mock.patch('neutron.agent.linux.utils.ensure_dir')
+    @mock.patch('neutron_lbaas.services.loadbalancer.drivers.haproxy.'
+                'jinja_cfg.save_config')
     @mock.patch('neutron.agent.linux.ip_lib.IPWrapper')
-    def test_spawn(self, ip_wrap, jinja_save, ensure_tree):
+    def test_spawn(self, ip_wrap, jinja_save, ensure_dir):
         mock_ns = ip_wrap.return_value
         self.driver._spawn(self.lb)
         conf_dir = self.driver.state_path + '/' + self.lb.id + '/%s'
@@ -484,30 +426,11 @@ class TestHaproxyNSDriver(base.BaseTestCase):
             namespace=namespace_driver.get_ns_name(self.lb.id))
         mock_ns.netns.execute.assert_called_once_with(
             ['haproxy', '-f', conf_dir % 'haproxy.conf', '-p',
-             conf_dir % 'haproxy.pid'], addl_env=None, run_as_root=True)
+             conf_dir % 'haproxy.pid'])
         self.assertIn(self.lb.id, self.driver.deployed_loadbalancers)
         self.assertEqual(self.lb,
                          self.driver.deployed_loadbalancers[self.lb.id])
 
-    @mock.patch('oslo_utils.fileutils.ensure_tree')
-    @mock.patch('neutron_lbaas.drivers.haproxy.jinja_cfg.save_config')
-    def test_spawn_enable_usage(self, jinja_save, ensure_tree):
-        with mock.patch.object(external_process.ProcessManager,
-                               'enable') as mock_enable:
-            self.driver._spawn(self.lb)
-            mock_enable.assert_called_once_with()
-
-    @mock.patch('oslo_utils.fileutils.ensure_tree')
-    @mock.patch('neutron_lbaas.drivers.haproxy.jinja_cfg.save_config')
-    def test_spawn_reload_cfg_usage(self, jinja_save, ensure_tree):
-        with mock.patch.object(external_process.ProcessManager, 'active',
-                               return_value=True):
-            with mock.patch.object(external_process.ProcessManager,
-                                   'reload_cfg') as mock_reload_cfg:
-                extra_cmd_args = ['-sf', '123']
-                self.driver._spawn(self.lb, extra_cmd_args=extra_cmd_args)
-                mock_reload_cfg.assert_called_once_with()
-
 
 class BaseTestManager(base.BaseTestCase):
 
@@ -595,7 +518,6 @@ class TestLoadBalancerManager(BaseTestLoadBalancerManager):
         self.lb_manager.refresh.assert_called_once_with(self.in_lb)
 
     def test_get_stats(self):
-        self.driver.get_stats.return_value = {'members': {}}
         self.lb_manager.get_stats(self.in_lb.id)
         self.driver.get_stats.assert_called_once_with(self.in_lb.id)
 
@@ -614,7 +536,6 @@ class BaseTestListenerManager(BaseTestLoadBalancerManager):
         self.listener2 = data_models.Listener(id='listener2')
         self.in_listener.loadbalancer = self.in_lb
         self.listener2.loadbalancer = self.in_lb
-        self.in_lb.listeners = [self.in_listener, self.listener2]
         self.refresh = self.driver.loadbalancer.refresh
 
 
@@ -651,8 +572,7 @@ class TestListenerManager(BaseTestListenerManager):
         self.driver.reset_mock()
         self.listener_manager.delete(self.listener2)
         self.assertFalse(self.refresh.called)
-        self.driver.undeploy_instance.assert_called_once_with(
-            self.in_lb.id, delete_namespace=True)
+        self.driver.undeploy_instance.assert_called_once_with(self.in_lb.id)
 
 
 class BaseTestPoolManager(BaseTestListenerManager):
@@ -661,9 +581,7 @@ class BaseTestPoolManager(BaseTestListenerManager):
         super(BaseTestPoolManager, self).setUp()
         self.in_pool = data_models.Pool(id='pool1')
         self.in_listener.default_pool = self.in_pool
-        self.in_pool.loadbalancer = self.in_lb
-        self.in_pool.listeners = [self.in_listener]
-        self.in_lb.pools = [self.in_pool]
+        self.in_pool.listener = self.in_listener
 
 
 class TestPoolManager(BaseTestPoolManager):
@@ -744,6 +662,28 @@ class TestHealthMonitorManager(BaseTestHealthMonitorManager):
 
 class TestNamespaceDriverModule(base.BaseTestCase):
 
+    @mock.patch('os.path.exists')
+    @mock.patch('neutron.agent.linux.utils.execute')
+    def test_kill_pids_in_file(self, execute, exists):
+        pid_path = '/var/lib/data'
+        with mock.patch('__builtin__.open') as m_open:
+            exists.return_value = False
+            file_mock = mock.MagicMock()
+            m_open.return_value = file_mock
+            file_mock.__enter__.return_value = file_mock
+            file_mock.__iter__.return_value = iter(['123'])
+            namespace_driver.kill_pids_in_file(pid_path)
+            # sometimes fails
+            # exists.assert_called_once_with(pid_path)
+            self.assertFalse(m_open.called)
+            self.assertFalse(execute.called)
+
+            exists.return_value = True
+            execute.side_effect = RuntimeError
+            namespace_driver.kill_pids_in_file(pid_path)
+            # sometimes fails
+            # execute.assert_called_once_with(['kill', '-9', '123'])
+
     def test_get_ns_name(self):
         ns_name = namespace_driver.get_ns_name('woohoo')
         self.assertEqual(namespace_driver.NS_PREFIX + 'woohoo', ns_name)
