@@ -1,4 +1,4 @@
-# Copyright 2015 Citrix Systems
+# Copyright 2014 Citrix Systems
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -14,21 +14,27 @@
 
 import mock
 
-from neutron_lbaas.drivers.netscaler import ncc_client
-from neutron_lbaas.drivers.netscaler import netscaler_driver_v2
+from neutron_lbaas.drivers.netscaler \
+    import netscaler_driver_v2
 from neutron_lbaas.services.loadbalancer import data_models
-from neutron_lbaas.tests.unit.db.loadbalancer import test_db_loadbalancerv2
+from neutron_lbaas.services.loadbalancer.drivers.netscaler import ncc_client
+from neutron_lbaas.tests.unit.db.loadbalancer import test_db_loadbalancer
 
-LBAAS_DRIVER_CLASS = ('neutron_lbaas.drivers.netscaler.netscaler_driver_v2'
+
+LBAAS_DRIVER_CLASS = ('neutron_lbaas.services.loadbalancer.drivers'
+                      '.netscaler.netscaler_driver_v2'
                       '.NetScalerLoadBalancerDriverV2')
 
-NCC_CLIENT_CLASS = ('neutron_lbaas.drivers.netscaler.ncc_client.NSClient')
+NCC_CLIENT_CLASS = ('neutron_lbaas.services.loadbalancer.drivers'
+                    '.netscaler.ncc_client'
+                    '.NSClient')
 
 LBAAS_PROVIDER_NAME = 'NetScaler'
 LBAAS_PROVIDER = ('LOADBALANCERV2:%s:%s:default' %
                   (LBAAS_PROVIDER_NAME, LBAAS_DRIVER_CLASS))
 
-log_path = ('neutron_lbaas.drivers.logging_noop.driver.LOG')
+log_path = ('neutron_lbaas.services.loadbalancer.drivers.'
+            'logging_noop.driver.LOG')
 
 
 class FakeModel(object):
@@ -68,14 +74,14 @@ class ManagerTest(object):
         self.delete_failure(model)
 
     def _check_success_completion(self):
-        """Check if success_completion is called"""
+        """Check if sucess_completion is called"""
         successful_completion_mock = self.successful_completion_mock
         successful_completion_mock.assert_called_once_with(
             mock.ANY, self.model)
         successful_completion_mock.reset_mock()
 
     def _check_success_completion_with_delete(self):
-        """Check if success_completion is called with delete"""
+        """Check if success_compeletion is called with delete"""
         successful_completion_mock = self.successful_completion_mock
         successful_completion_mock.assert_called_once_with(
             mock.ANY, self.model, delete=True)
@@ -124,8 +130,8 @@ class ManagerTest(object):
     def check_op_status(self, model, delete=False):
         loadbalancer = model.root_loadbalancer
         if hasattr(self, "async_obj_track_list") and self.async_obj_track_list:
-            self.parent.assertIn(
-                loadbalancer.id, self.async_obj_track_list)
+            self.parent.assertTrue(
+                loadbalancer.id in self.async_obj_track_list)
         else:
             if delete:
                 self._check_success_completion_with_delete()
@@ -244,7 +250,7 @@ class MonitorManagerTest(ManagerTest):
 
 
 class TestNetScalerLoadBalancerDriverV2(
-        test_db_loadbalancerv2.LbaasPluginDbTestCase):
+        test_db_loadbalancer.LoadBalancerPluginDbTestCase):
 
     def _create_fake_models(self):
         id = 'name-001'
