@@ -15,8 +15,7 @@
 import contextlib
 
 import mock
-from neutron_lib import exceptions
-import six
+from neutron.common import exceptions
 
 from neutron_lbaas.services.loadbalancer.drivers.haproxy \
     import namespace_driver
@@ -33,13 +32,14 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         conf.haproxy.user_group = 'test_group'
         conf.haproxy.send_gratuitous_arp = 3
         self.conf = conf
+        self.mock_importer = mock.patch.object(namespace_driver,
+                                               'importutils').start()
+
         self.rpc_mock = mock.Mock()
-        with mock.patch(
-                'neutron.common.utils.load_class_by_alias_or_classname'):
-            self.driver = namespace_driver.HaproxyNSDriver(
-                conf,
-                self.rpc_mock
-            )
+        self.driver = namespace_driver.HaproxyNSDriver(
+            conf,
+            self.rpc_mock
+        )
         self.vif_driver = mock.Mock()
         self.driver.vif_driver = self.vif_driver
 
@@ -47,7 +47,6 @@ class TestHaproxyNSDriver(base.BaseTestCase):
             'pool': {'id': 'pool_id', 'status': 'ACTIVE',
                      'admin_state_up': True},
             'vip': {'id': 'vip_id', 'port': {'id': 'port_id'},
-                    'address': '10.0.0.2',
                     'status': 'ACTIVE', 'admin_state_up': True}
         }
 
@@ -58,7 +57,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         return mock.call(**kwargs)
 
     def test_get_name(self):
-        self.assertEqual(namespace_driver.DRIVER_NAME, self.driver.get_name())
+        self.assertEqual(self.driver.get_name(), namespace_driver.DRIVER_NAME)
 
     def test_create(self):
         with mock.patch.object(self.driver, '_plug') as plug:
@@ -66,7 +65,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                 self.driver.create(self.fake_config)
 
                 plug.assert_called_once_with(
-                    'qlbaas-pool_id', {'id': 'port_id'}, '10.0.0.2'
+                    'qlbaas-pool_id', {'id': 'port_id'}
                 )
                 spawn.assert_called_once_with(self.fake_config)
 
@@ -74,7 +73,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         with contextlib.nested(
             mock.patch.object(self.driver, '_get_state_file_path'),
             mock.patch.object(self.driver, '_spawn'),
-            mock.patch.object(six.moves.builtins, 'open')
+            mock.patch('__builtin__.open')
         ) as (gsp, spawn, mock_open):
             mock_open.return_value = ['5']
 
@@ -261,7 +260,6 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                      'fixed_ips': [{'ip_address': '10.0.0.2',
                                     'subnet': {'cidr': '10.0.0.0/24',
                                                'gateway_ip': '10.0.0.1'}}]}
-        test_address = '10.0.0.2'
         with contextlib.nested(
                 mock.patch('neutron.agent.linux.ip_lib.device_exists'),
                 mock.patch('netaddr.IPNetwork'),
@@ -272,7 +270,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
             ip_net.return_value = ip_net
             ip_net.prefixlen = 24
 
-            self.driver._plug('test_ns', test_port, test_address)
+            self.driver._plug('test_ns', test_port)
             self.rpc_mock.plug_vip_port.assert_called_once_with(
                 test_port['id'])
             self.assertTrue(dev_exists.called)
@@ -297,8 +295,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
 
             dev_exists.return_value = True
             self.assertRaises(exceptions.PreexistingDeviceFailure,
-                              self.driver._plug, 'test_ns', test_port,
-                              test_address, False)
+                              self.driver._plug, 'test_ns', test_port, False)
 
     def test_plug_not_send_gratuitous_arp(self):
         self.conf.haproxy.send_gratuitous_arp = 0
@@ -308,7 +305,6 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                      'fixed_ips': [{'ip_address': '10.0.0.2',
                                     'subnet': {'cidr': '10.0.0.0/24',
                                                'gateway_ip': '10.0.0.1'}}]}
-        test_address = '10.0.0.2'
         with contextlib.nested(
                 mock.patch('neutron.agent.linux.ip_lib.device_exists'),
                 mock.patch('netaddr.IPNetwork'),
@@ -319,7 +315,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
             ip_net.return_value = ip_net
             ip_net.prefixlen = 24
 
-            self.driver._plug('test_ns', test_port, test_address)
+            self.driver._plug('test_ns', test_port)
             cmd = ['route', 'add', 'default', 'gw', '10.0.0.1']
             expected = [
                 self._ip_mock_call('test_ns'),
@@ -332,7 +328,6 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                      'mac_address': 'mac_addr',
                      'fixed_ips': [{'ip_address': '10.0.0.2',
                                     'subnet': {'cidr': '10.0.0.0/24'}}]}
-        test_address = '10.0.0.2'
         with contextlib.nested(
                 mock.patch('neutron.agent.linux.ip_lib.device_exists'),
                 mock.patch('netaddr.IPNetwork'),
@@ -343,7 +338,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
             ip_net.return_value = ip_net
             ip_net.prefixlen = 24
 
-            self.driver._plug('test_ns', test_port, test_address)
+            self.driver._plug('test_ns', test_port)
             self.rpc_mock.plug_vip_port.assert_called_once_with(
                 test_port['id'])
             self.assertTrue(dev_exists.called)
@@ -359,8 +354,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
             self.assertFalse(ip_wrap.called)
             dev_exists.return_value = True
             self.assertRaises(exceptions.PreexistingDeviceFailure,
-                              self.driver._plug, 'test_ns', test_port,
-                              test_address, False)
+                              self.driver._plug, 'test_ns', test_port, False)
 
     def test_plug_gw_in_host_routes(self):
         test_port = {'id': 'port_id',
@@ -371,7 +365,6 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                                                'host_routes':
                                                [{'destination': '0.0.0.0/0',
                                                  'nexthop': '10.0.0.1'}]}}]}
-        test_address = '10.0.0.2'
         with contextlib.nested(
                 mock.patch('neutron.agent.linux.ip_lib.device_exists'),
                 mock.patch('netaddr.IPNetwork'),
@@ -382,7 +375,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
             ip_net.return_value = ip_net
             ip_net.prefixlen = 24
 
-            self.driver._plug('test_ns', test_port, test_address)
+            self.driver._plug('test_ns', test_port)
             self.rpc_mock.plug_vip_port.assert_called_once_with(
                 test_port['id'])
             self.assertTrue(dev_exists.called)
@@ -411,7 +404,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
     def test_kill_pids_in_file(self):
         with contextlib.nested(
             mock.patch('os.path.exists'),
-            mock.patch.object(six.moves.builtins, 'open'),
+            mock.patch('__builtin__.open'),
             mock.patch('neutron.agent.linux.utils.execute'),
             mock.patch.object(namespace_driver.LOG, 'exception'),
         ) as (path_exists, mock_open, mock_execute, mock_log):
